@@ -19,7 +19,7 @@
 
 '''Common classes and functions for package tests.'''
 
-import string, random, crypt, subprocess, pwd, grp,  signal, time, unittest, tempfile, shutil, os, os.path, re, glob
+import string, random, subprocess, pwd, grp,  signal, time, unittest, tempfile, shutil, os, os.path, re, glob
 import sys, socket, gzip
 from stat import *
 
@@ -1080,11 +1080,9 @@ class TestUser:
                 if not login_exists(login):
                     break
 
-        self.salt = random_string(2)
         self.password = random_string(8,lower=lower)
-        self.crypted = crypt.crypt(self.password, self.salt)
 
-        creation = ['useradd', '-p', self.crypted]
+        creation = ['useradd']
         if home:
             creation += ['-m']
         if group:
@@ -1095,6 +1093,8 @@ class TestUser:
             creation += ['-s',shell]
         creation += [login]
         assert subprocess.call(creation) == 0
+        # mjt: this should run /usr/sbin/chpasswd directly feeding it with login:self.password but I don't know python enough
+        assert subprocess.call(['debian/tests/chpasswd', login, self.password]) == 0
         # Set GECOS
         assert subprocess.call(['usermod','-c','Buddy %s' % (login),login]) == 0
 
